| Title: | Data files for the 'swephR' package |
|---|---|
| Description: | Data files to provide the full Swiss Ephemeris for usage with the 'swephR' package. |
| Authors: | Ralf Stubner |
| Maintainer: | Ralf Stubner <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-05-17 09:29:19 UTC |
| Source: | https://github.com/rstub/swephRdata |
Data files to provide the full Swiss Ephemeris for usage with the 'swephR' package.
The DESCRIPTION file:
| Package: | swephRdata |
| Type: | Package |
| Title: | Data files for the 'swephR' package |
| Version: | 0.0.1 |
| Author: | Ralf Stubner |
| Maintainer: | Ralf Stubner <[email protected]> |
| Description: | Data files to provide the full Swiss Ephemeris for usage with the 'swephR' package. |
| License: | GPL (>= 2) |
| Repository: | https://rstub.r-universe.dev |
| Date/Publication: | 2026-04-17 19:35:31 UTC |
| RemoteUrl: | https://github.com/rstub/swephRdata |
| RemoteRef: | HEAD |
| RemoteSha: | 2a009327cfa20cd776b8b6e80b84521e7e1fe7ea |
Index of help topics:
swephRdata-package Data files for the 'swephR' package
This section should provide a more detailed overview of how to use the package, including the most important functions.
Ralf Stubner
Maintainer: Ralf Stubner <[email protected]>
This optional section can contain literature or other references for background information.
Optional links to other man pages
## Optional simple examples of the most important functions ## Use \dontrun{} around code to be shown but not executed## Optional simple examples of the most important functions ## Use \dontrun{} around code to be shown but not executed